---
date: "2021-02-03T22:16:00Z"
title: "RSS: The Rise and Fall... and Rise Again"
description: "An opinion piece on RSS, its popularity over the last couple of decades, and how it can make a resurgence again."
tags: [100daystooffload, technology, opinion]
---

Many people would consider RSS - Really Simple Syndication - to be a relic of the past. However I think it has been making a comeback.

RSS is a mechanism by which people can automatically receive updates from individual websites, similar to how you might follow another user on a social networking service. Software known as RSS _readers_ can be used to subscribe to RSS _feeds_ in order to receive these updates. As new content (e.g. a blog post) is published to an RSS-enabled website, its feed is updated and your RSS reader will show the new post the next time it refreshes. Many RSS readers have an interface similar to an email client, with read/unread states, folders, favourites, and more.

## The rise

RSS was [first released](https://en.wikipedia.org/wiki/RSS) in early 1999, and it steadily gained popularity amongst content producers and consumers, with adopters from media outlets and software implementations making their way into early Internet Eplorer and Firefox versions, amongst others. These were the days before the "real" [Web 2.0](https://en.wikipedia.org/wiki/Web_2.0) hit, and in which websites were very much more silos of information. Tools like RSS were powerful then because they enabled the easy _aggregation_ of information from multiple sources.

Not too long after this (Web 2.0 'began' in the mid 2000's), and during the years ever since, mainstream social networks became ubiquitous. Many people flock(ed) to these as a way to share and subscribe (by following others) to receive updates in real time, several times a day and from lots of different people and organisations. These services enabled features far beyond aggregation by allowing easy sharing, rating (e.g. likes) and commentating such that today such services have become the primary means of information and news sharing and reception for many people.

## The fall(?)

At that time RSS was still very much "a thing" for many people (though the [discontinuation of the hugely popular Google Reader in 2013](https://en.wikipedia.org/wiki/Google_Reader#Discontinuation) was a bit of a bummer to these communities). However new people now joining the web scene would be far more likely to instead engage with these extremely well-funded, well-marketed, and _centralised_ social platforms - [perfectly engeineered to be addictive](https://www.thesocialdilemma.com), entirely driven and propagated by [FOMO](https://en.wikipedia.org/wiki/Fear_of_missing_out), and focused on content-sharing (even if the content is often [misinformation](https://www.theguardian.com/technology/2021/jan/30/facebook-letting-fake-news-spreaders-profit-investigators-claim)) - where _you_ are the product, rather than spend the time researching and subscribing to individual RSS feeds.

To some commentators in this space the concept behind all of these social platforms is known as the _[fast web](https://jackcheng.com/essays/the-slow-web/#the-fast-web)_ - a web that tells you when and what information to consume rather than letting you make that decision for yourself. Facebook, Twitter, Instagram, and others all started as just a _chronological_ timeline of interesting content from friends and family. On all of these services today the "algorithm" determines what (and who) goes in your timeline, and it constantly learns what to feed you - and when - in order to get those few extra minutes from you each day. This is literally its business model.

What used to be an innocent bookmarking tool, Twitter's "favouriting" mechanism is now essentially a game of __retweet roulette__ in which the algorithm will every now and again choose to include your "bookmarks" (not just retweets) on the feeds of people who follow you. If that's not anxiety-inducing or user-hostile then I don't know what is!

Of course this is something Facebook has done for a while too, except perhaps in a more sinister way - such as implying [a user has liked something when they haven't at all](https://www.baekdal.com/thoughts/facebook-graph-search-privacy-woes).

Other social networking tools can be more user-friendly. For example, the open-source [Mastodon](https://en.wikipedia.org/wiki/Mastodon_(software)) software powers distributed social networks that aren't fuelled by addiction and instead give you more control over what you receive and where your posts go. However these tools still have some way to go to becoming anywere near mainstream.

I want to caveat some of the above: I obviously don't think any of this is the fault of the individual. These social platforms are fantastically easy places to set-up a web presence. Creating an Instagram, Facebook, or Tik-Tok account for you (or your business) takes literal seconds. Within a minute you can have your profile setup and be following a dozen people, and already getting engagement and "reactions" from others (remember those "Your friend, X, is now on Instagram!" type notifications?).

With all of this power and efficiency at the fingertips it's no wonder that people don't create their own personal websites anymore, or feel the need to reach out to actively keep-up with other such sites. What's the point in re-inventing the wheel when I can easily create a Facebook page for myself that includes an inbuilt blog "feed", a space for links, photos, and more? And it's "free"! The barrier to creating a self-owned personal space on the internet for yourself is considered too high for most people, and is probably still seen as "geeky" even if it does come with all the benefits of privacy and control.

And I'm not saying that self-owned spaces, RSS, and that whole ecosystem are related, or the opposite to, mainstream social media; more that it is a useful way to compare and contrast different ways of accessing and disseminating information and the level of control one has over this.

This probably feels like I'm going way off-piste, and I sort of have, but my key meaning here is that for several years the concept of RSS has evaporated from popular knowledge because people haven't _needed_ it - either as a tool for receiving _or_ disseminating information. Ask your non-tech friends and family if they've heard of RSS (and know what it is for a bonus point) - I bet the positive response rate will be low in most cases, especially in younger respondents.

Also, I don't think this is solely the fault of the social giants. Online media outlets - which would have needed to rely on RSS for years before online social media became more mainstream - now often completely ignore it or treat it as a second-class citizen.

The [BBC News website](https://www.bbc.co.uk/news) happily displays large friendly icons for Facebook, Twitter, and the like, but no mention of RSS (try `ctrl-F`). In fact, you'll probably need to search the web for "bbc rss" in order to find the RSS feeds that are [listed on a page that hasn't been updated for over a decade](https://www.bbc.co.uk/news/10628494) and which still lists IE7 and the long-discontinued Google Reader as sensible options (though ironically I suppose this does indicate the stability and robustness of the RSS system).

## The rise again

Anyway, all that sounds a bit doom and gloom but I definitely think we are starting to see a shift in people's attitude towards and - importantly, trust in - these big tech companies. Facebook's recent attitiude towards information collection (and subsequent sharing) has [hit mainstream headlines](https://www.independent.co.uk/life-style/gadgets-and-tech/facebook-update-apple-privacy-ads-b1795916.html) and everyone must have seen [Whatsapp's popup about data sharing](https://www.techradar.com/news/whatsapps-new-privacy-policy-requires-you-to-share-data-with-facebook). Too much uncertainty undermines the trust in these platforms, and people have understandably sought out other options. A few weeks ago Telegram reported an addition of [25 million new users within 72 hours](https://www.androidpolice.com/2021/01/12/telegram-adds-25-million-new-users-in-just-72-hours-as-rival-apps-falter) as a result of these policy "changes".

My parents aren't really tech-aware at all but even they were telling me last week on a video call about this "new app Signal" they had downloaded and begun to use with their friends - without any of my input.

I'm not sure what it is, but people seem to _care_ more about their data these days. Whether that's because of GDPR, the fact that coronavirus means people aren't endlessly scrolling through social feeds on their daily commutes anymore, or something else or a mixture of everything. And that extends to being more picky about the information they receive too.

Either way, I've noticed more and more [posts like this](https://atthis.link/blog/2021/rss.html) (and the subsequent [reactions and discussions](https://news.ycombinator.com/item?id=26014344)) recently, and the [#100DaysToOffload](https://100daystooffload.com) movement has brought about a surge in people - myself included, really - creating their own longer-form content, for which RSS is a perfect distribution mechanism.

I think we're on a bit of a brink representing a general - but real - change in attitude from people towards data, and the time that they choose to give to now lesser-trusted platforms. It is our responsibility to help educate about the alternative options so that those around us can make their own decisions. Whilst I am relatively new to RSS in the grand scheme of things (having only really started properly engaging with it about a year ago), it already makes me feel more in control of what I view, and when.

Whilst this concept doesn't need to be limited to RSS, it's a great starting point as it's easy to understand. It "feels" friendly, it helps power connections to the decentralised and [small web](https://ar.al/2020/08/07/what-is-the-small-web/).

It, as a concept, has no business model. Though of course you can pay for the software you use, and websites can make money through ads, but at least you have a _choice_ regarding who you subscribe to and the software you use to do it through (and [there are lots of choices](https://en.wikipedia.org/wiki/Comparison_of_feed_aggregators)). You aren't tied into anything and it respects your privacy - you don't need to "sign-up", provide your details, and sites don't know that _you_ personally have subscribed.

RSS may be age-old, but it is an excellent way to still get the information you need as you begin to use mainstream social media less, and - although it doesn't need to be slow in itself - it is a fantastic tool to combine with the growing and user-respecting world of the [slow web](https://jackcheng.com/essays/the-slow-web#timely-vs-real-time), in which timeliness (where you're in control) is far more important than "real-time".

--

### Edit

I've received some replies to this post that talk about the lack of mentions of the [Atom standard](https://en.wikipedia.org/wiki/Atom_(Web_standard)) and podcasts. RSS certainly is (and has been) a fantastic way to subscribe to podcasts. Its flexibility and ease of use has been a great tool for both content creators and consumers, and has helped to build the ecosystem of podcast apps and services we see today. And of course, there are other very useful distribution mechanisms and standards available for distributing information, such as Atom. This post was focused more on contrasting this family of systems with what many people may consider "mainstream" services, and how the wide adoption of the latter has perhaps had an effect on the former.