---
date: "2021-02-25T13:46:00Z"
title: "Migrating from Google Photos: Nextcloud, Piwigo, Mega, and pCloud"
description: "My experiences with trying to move away from Google Photos."
tags: [100daystooffload, technology, opinion]
---

By now I'm sure everyone has heard the horror stories about people (seemingly-) randomly losing access to their Google accounts. Often the account closures are reported to have been accompanied with vague automated notifications from Google complaining that the account-holder violated their terms in some way, but without any specific details or an offer of appeal or process to resolve the "issues" and reinstate the accounts.

As such, these events usually mark the end of the road for the victims' presence and data on Google platforms - including Gmail, Drive, Photos, YouTube - without having any option to extract the data out first. This could be years' worth of documents, family photos, emails, Google Play purchases, and much more (ever used "Sign in with Google" on another service, for example?).

Some affected people are fortunate to have a large social media following to ensure that their posts describing this treatment can traverse the networks enough to get through to someone close to Google who can try and elevate it in order to get accounts reinstated. However, for most people this is not possible.

The [creator of Stardew Valley](https://twitter.com/Demilogic) recently [found himself locked out of his 15-year-old Google account](https://twitter.com/Demilogic/status/1358661840402845696) - even whilst involved in a key ongoing deal with Stadia, which he has since pulled out from due to feeling mal-treated. There are many similar stories available, and probably thousands more we never hear about.

Of course, I am sure there are legitimate reasons for many accounts to be removed and that the original intentions behind these automated systems were good. Either way, this still just worries me. Whilst I haven't (at least, I don't think?) done anything to violate any terms, I just don't want to take the risk and wake up one morning to find I have lost 15 years' worth of emails, photos, and documents.

## What are the alternatives?

These days there are so many services that compete with Google's own offerings. For example, [DuckDuckGo](https://duckduckgo.com) is excellent for web search - though several times a day I do need to revert to Google search for more complex queries (which I can do by prepending DuckDuckGo search queries with `g!`). There are [many websites that list good alternatives to Google services](https://restoreprivacy.com/google-alternatives), and I won't bang on about these ideas here - it's up to you what you prefer to use, of course, and this type of thing has been covered many times before.

Personally, I've used my own domain to send and receive email (using [Fastmail](https://www.fastmail.com)) for several years now, and self-host my files and documents using [Nextcloud](https://nextcloud.com). I don't really use YouTube or have much data tied-up in the other Google offerings.

However the one service I do rely on still is Google Photos. To be fair, this is a fantastic service - the apps seamlessly back everything up, the search is great (it's Google's bread-and-butter, after all), and I can easily and instantly find specific photos from two decades ago, or from any time in-between. It's also super fast. I'd never found a good-enough replacement for media storage and so I never made the leap.

## The problems with media storage

Images and videos - espcially with modern cameras and phones - take up a _huge_ amount of space. I take a few pictures every day, and on my messenger apps I sometimes like to save images I receive from friends and family too.

This has resulted in a collection of over 84,000 pictures and videos in a mostly-continuous stream since 1998 - the year our family got our first digital camera. There are also digitised versions of photos from as early as 1959 on there too. Whilst this is not a massive collection by any standards these days, it forms a significant part of my own data footprint.

Whilst I was happy with using Google for this one area, I would get so nervous every time I read one of those "deleted accounts" stories that it got to the point where last month I finally committed to making a change.

In the meantime I needed to try and get my stuff out of Google Photos. The service lets you download 500 images at a time from the web interface, but that would have taken forever. The other option was to use [Google Takeout](https://google.com/takeout). I did this and shortly after received an email containing links to download 48 different archives of data.

![Email from Google Takout listing lots of download buttons](/media/blog/google-takeout-email.png)

When I downloaded a couple of examples, I saw that they seemed to contain a lot of JSON metadata files and not many actual photos. I imagined I'd have to download the whole lot to try and make sense of it all and manually piece bits together. I thought I'd leave that for now whilst I continued my search for an alternative service, and come back to that problem later.

## The search for a Google Photos alternative

The first job was to identify a new process/system for media storage. I had a few acceptance criteria in mind;

- It needed to be affordable (not necessarily as cheap as [Google One](https://one.google.com), but not bank-breaking either).
- I needed it to be quickly and easily navigable (i.e. to easily move to a particular date to find photos).
- It had to have some type of auto-sync from my phone's photo gallery (I am too lazy to remember to manually "back-up" things - I need automation!).

I was already using Nextcloud for my documents anyway, and the Nextcloud app (which is brilliant) also includes an auto-upload feature for photos. However, I find Nextcloud gets a bit slow and grinds my server to a halt when viewing (I guess it processes things in the background?) large and recently-uploaded photos. Also, my VPS provider's pricing (not unreasonable) would mean forking out the best part of $400 a year for the required block storage - which would only increase every year as my library gets bigger.

I also considered [Piwigo](https://piwigo.org), which looks great and is [reported to be very fast](https://piwigo.org/testimonials). However the self-hosted option would have the same pricing implications as Nextcloud (above), and the hosted offering would be [significantly more](https://piwigo.com/pricing) if I was to include videos too. I think Piwigo is aimed more at photographers maintaining and sharing albums rather than for use as a personal photo storage solution.

I [recently tooted](https://fosstodon.org/web/statuses/105692084325464954) out to the community about this problem and I got some great responses back. One idea in particular caught my eye: [Mega](https://mega.nz). I had used Mega before a while back, and the apps and web interfaces seemed to have come on a long way in recent years. After a bit of research I decided to choose this option. It seemed secure (with client-side encryption), quick, and the apps had the features I needed.

I went to pay for Mega (using the web browser), and it redirected me to a very dodgy-looking payment website - this threw me a little. I went back to the checkout page to see if I had clicked the wrong thing, clicked "confirm" again, and this time it took me to an entirely _different_ (but still sort of dodgy-looking) payment site. I've set-up [Stripe](https://stripe.com) a few times before, and know it's pretty trivial these days to accept card payments on your own site, and so alarm bells began to ring a little. My paranoid security-focused self was put off enough to continue my search.

## Migrating to pCloud

That's when I stumbled upon the Swiss-based [pCloud](https://www.pcloud.com) on a Reddit thread discussing storage alternatives. It seems to be pretty feature-matched with Mega, despite not offering client-side encryption out-of-the-box - but then neither does Google Photos. Additionally, pCloud offers both US and European servers.

pCloud's apps have similar functions to Mega, and the service also has the added bonus of offering a Google Drive integration! Hopefully this would mean I wouldn't need to spend ages traversing that Google Takeout mess. The service also offers integrations with Dropbox, OneDrive, and some social networking platforms.

I signed-up and paid - without needing to go to any dodgy sites. I then linked my Google account and waited for the magic to happen.

It was a little slow. I know there was a fair amount of data, and I imagine the combination of this plus Google rate-limiting and other factors contributed to the speed too. I checked every few hours on the progress; there's a sort of indicator (a folder count), but otherwise there was no way to really check what was going on. After a couple of days I noticed it had stopped (or "aborted") by itself.

![Screenshot of pCloud, showing Google Drive import aborted](/media/blog/pcloud-google-drive.png)

I had a quick browse through what pCloud had brought through and could see it had got to around July 2019 before it had had enough. This was OK - it had imported the vast majority and I was happy enough to run through the last couple of years' worth of content on Google Photos, downloading 500 photos at a time to manually upload to pCloud in order to plug the gap. 

I then un-linked my Google account from pCloud. I turned off Google Photos auto-upload from my phone and instead all new media now gets auto-uploaded to pCloud. Job done.

## Final thoughts

pCloud's navigation seems to be pretty quick, and uploading content is also very fast. It's not _perfect_, though (is anything?) - viewing photos on the app can take a few seconds to generate/retrieve thumbnails, and it doesn't have the smoothness that Google Photos offers.

However, it's great for now. I have a _"tangible"_ folder of media that feels more portable in case I ever need to move again. pCloud also has clear channels for communication if I do ever need to get in touch, and I certainly feel as though I am less subject to automated judgments from unruly algorithms.
