---
date: "2021-04-04T11:10:00Z"
title: "From Apple Mail to Spark to Thunderbird"
description: "Three months: three mail clients. Some thoughts."
tags: [100daystooffload, technology, opinion]
---

Like many people, I own and manage multiple email accounts - for example, some are for work, for home, or for specific projects. I used to be a strong user of solely web-based email clients (such as Gmail or Fastmail's web apps) for each of my accounts. However the number of tabs I needed to keep open for all of this grew to the point where things became unmanageable - both in terms of needing to check multiple tabs several times per day and also frustrations when the browser would restart, or if I'd lose my tab setup for some other reason.

I needed a proper client, and although I knew that web-based software like [Roundcube](https://roundcube.net) and [Rainloop](https://www.rainloop.net) existed - which I could self-host - they just never felt stable or feature-ful enough.

This post is a short round-up of three mail clients I've been trying over the past few months.

## Apple Mail

For several years I've been an Apple Mail user on both my Mac and iPhone - mainly because it was the default on the devices I have but also because it's generally quite smooth and works reliably.

It's relatively painless to get setup, and the accounts sync well across the mail, contacts, and calendar apps. On Gmail (and other larger providers) there is an authentication "wizard" to help get the accounts setup. Fastmail allows you to [install profiles](https://www.fastmail.help/hc/en-us/articles/1500000279941-Set-up-iOS-devices-iOS-12) that automatically configure everything for you.

However, over time I began to find the interface a bit unintuitive. On iOS the general "Accounts" setting - which was useful as a single source of truth - seemed to disappear, and for some mailboxes it wouldn't let me add alias send-from addresses. I'm sure there was a reason for this, but I sometimes find that the iOS settings UIs overcomplicate things in their efforts for simplicity.

Whilst the Mac (currently) still has a dedicated Accounts setting in System Preferences, it also had other problems. Several times a day I'd frustratingly get my workflow interrupted by warnings of network problems.

![Apple Mail 'accounts offline' warning](/media/blog/apple-mail-issue.png)

I still think Apple Mail is a pretty decent app, but I thought that there must be something else out there that would work better, and be less frustrating, for me.

## Spark Mail

Back in February some of my colleagues recommended the [Spark mail app](https://sparkmailapp.com) from [Readdle](https://readdle.com). I've used some of Readdle's other software in the past (see [this post](/blog/2021/03/08/getting-mail), for example), and generally find it quite useful and intuitive. Like Apple Mail, it's also available for Mac and iOS.

Spark is free to get started (and I imagine most individuals would fit into their [free plan](https://sparkmailapp.com/pricing) long-term too). One of the features I immediately liked was that all of your mail accounts are tied to a single account. That means that if you get a new computer or phone, you don't need to go through the tedious business of setting up all the mail accounts again - just login with your main email and everything else gets pulled-through.

Email management is easy, search is lightning-fast, and the settings are useful.

Spark also comes bundled with a calendar that syncs well and automatically with services like Google Calendar and Fastmail Calendar. Like Apple Mail, there are dedicated setup wizards for email and calendar with the larger providers, and an option for manual entry for others. The calendar's event creator is nice, and also allows you to automatically schedule a video meeting.

![Spark calendar video meeting picker](/media/blog/spark-calendar-meeting.png)

One drawback is that there doesn't seem to be any way to view or manage contacts, and neither does it seem to integrate with the system contacts. I imagine it works directly with the relevant provider's contacts service.

Another frustration I had was in managing shared calendars. I think I'm a bit of a calendar power-user, however I imagine this must be affecting other people too. If someone else - who also shares their calendar with you - creates an event and invites you to it, there does not seem to be any way to select your own entry in order to interact with it (e.g. to accept or decline the invitation).

In the event below, if my calendar was the "green" one, for example, there is no way for me to select that in order to accept or decline. Again, I may be missing something but I've been trying to find a way for a while now without needing to "hide" my colleagues' calendars first.

![Spark calendar event with multiple attendees](/media/blog/spark-calendar-selection.png)

Then it comes to security. Whilst I "trust" Readdle - in that I imagine they have decent security practices in place - we know that even the most secure companies can become compromised. The account sync feature mentioned earlier is certainly useful, however this must mean that Readdle are storing the Gmail access keys or IMAP connection details on their own servers in a centralised location. Your email is the last thing you want to get compromised - since it is likely that this controls a number of your other online accounts - and so this risk is a bit of a concern.

Readdle [claim that](https://sparkmailapp.com/blog/privacy-explained) everything is encrypted at various levels but it still feels a little risky to me. Having the sync and push notifications is useful, and so it's up to the individual to choose what works best for them.

## Thunderbird

The last client I want to mention in this post is [Mozilla's Thunderbird](https://www.thunderbird.net). This is a bit of a re-visit for me, since this is the client I used consistently during my University years.

In honesty, the client doesn't seem to have changed a huge amount over the last decade, but then again - neither have the underlying email technologies themselves. It's an open-source client available on a number of operating systems - but not yet ([or ever?](https://support.mozilla.org/en-US/questions/990147)) for mobile.

Despite the slower development, I find Thunderbird to be a very powerful client. It has great support for email, calendar, and contacts straight out of the box. Things seem clearly organised, and account-management is super easy. There are no dedicated setups for Gmail, Outlook, etc., but it was able to automatically detect the relevant IMAP/SMTP servers for all of my accounts.

It's very unopinionated about ordering, views, threading, and much more - which allows you to set things up the way that works best for you. The interface doesn't try to be flashy or too clean and I find I am very productive when using it.

The calendar is easy to use and works with open standards like CalDAV.

It also has built in support for chat through systems like IRC and XMPP (if you use these types of things), and there's also a rich ecosystem of plugins to add extra functionality too. It's certainly the most flexible and powerful of the desktop mail apps I've used.

A few areas where it frustrates are around its performance. When adding a new account it proceeds to automatically download all of the mail headers for that account to be stored locally in its databases. This allows it to support searching and other local tasks, but the process causes the app to run slowly whilst it's in progress. If you change computer often, or have several machines to setup, then this could be a pain.

When opening large mail folders containing perhaps several hundreds of thousands of messages - for example my combined "Archive" folder - things get _very_ slow to the point where it is unusable. However, I don't really ever need to use these views so this isn't too much of a problem for me, but for some people this could be a blocker.

When compared to Apple Mail and Spark, the search function seems very slow. The results returned are quite accurate though, and the fact that results get shown in their own "tab" means that your flow isn't interruped elsewhere in the app. This is a nice feature.

Generally, I love Thunderbird. Mozilla is renowned for being privacy-centric and the fact that everything is stored locally gives me more confidence about its security. Of course, it has drawbacks which will put some people off, but it's good to be supporting open-source software where possible.

## Conclusion

Like a web browser, I think people should be free to continue to try alternative mail clients as their needs and the software features change. The software mentioned above comprise just a small sample, and are focused largely around the Apple ecosystems since these are the devices I happen to be using at the moment.

Some others I'd like to try are [Airmail](https://airmailapp.com) and [Polymail](https://polymail.io). However, it'd be great to get some feedback on what other people are using. If you have any suggestions then please get in touch using Matrix (@wilw:matrix.wilw.dev) or on Mastodon ([fosstodon.org/@wilw](https://fosstodon.org/@wilw)).

