import React from 'react'
import Helmet from 'react-helmet'

import Layout from '../components/Layout/Layout.js';
import ExternalLink from '../components/ExternalLink';
import Emoji from '../components/Emoji';

const ThisPage = () => {
  
  return (
    <Layout>
      <Helmet title='About this site'>
        <meta name="description" content="About how this website works and visitor privacy." />
      </Helmet>

      <h1>About this website</h1>

      <p>This website is my own space on the web on which I publish notes, blog posts, articles, projects, and more.</p>
      <p>Like others similar to me, I consider my site to be part of the <ExternalLink href="https://ar.al/2020/08/07/what-is-the-small-web/">Small Web</ExternalLink> - a collection of personal "people-focused" websites away from the ownership and tracking of large "big tech" companies.</p>
      <p>I believe that the more content given to centralised platforms makes the web un-even and gives control of information to a small number of big organisations.</p>
      <p>If you are able to set up your own space on the internet then it ensures that the web keeps belonging to everyone, and it allows information to flow more freely.</p>

      <h2><Emoji e='🤫' /> A note on privacy</h2>
      <p>I consider user privacy to be one of the most important factors when designing (and using) software - including websites.</p>
      <p>I do not track visitors to this site but I do use <ExternalLink href="https://simpleanalytics.com">Simple Analytics</ExternalLink> to understand where visitors come from and what content is viewed the most.</p>
      <p>Simple Analytics respects user privacy and <ExternalLink href="https://docs.simpleanalytics.com/dnt">respects "Do Not Track"</ExternalLink> settings if you have this enabled in your browser.</p>
      
      <h2><Emoji e='🤖' /> Technology</h2>
      <p>This is a static site built using <ExternalLink href="https://www.gatsbyjs.com">GatsbyJS</ExternalLink> - an open-source generator that leverages React to build performant websites.</p>
      <p>I deploy the site using <ExternalLink href="https://vercel.com">Vercel</ExternalLink>, which uses its network of CDN nodes to serve the static site assets.</p>
      <p>I use the <ExternalLink href="https://www.recursive.design/">Recursive</ExternalLink> font.</p>
      <p><ExternalLink href="https://www.happyhues.co">Happy Hues</ExternalLink> provides the inspiration for some of the colour themes.</p>
      <p>The content and layout is hand-made by me. You can check out <ExternalLink href="https://git.wilw.dev/wilw/wilw.dev">the source code</ExternalLink> if you're interested.</p>

      <h2><Emoji e='ℹ️' /> Other remarks</h2>
      <p>The content on this site represents my own thoughts and opinions, and does not necessarily reflect the opinions of the people and companies I work with and for.</p>
    </Layout>
  );
}

export default ThisPage
